@@ -356,17 +356,10 @@ cpufreq_prefs_dialog_response_cb (CPUFreqPrefs *prefs,
         GError *error = NULL;
 
         if (response == GTK_RESPONSE_HELP) {
-#if GTK_CHECK_VERSION (3, 22, 0)
 		gtk_show_uri_on_window (GTK_WINDOW (prefs->priv->dialog),
 	                            "help:mate-cpufreq-applet/cpufreq-applet-prefs",
 	                            gtk_get_current_event_time (),
 	                            &error);
-#else
-		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (prefs->priv->dialog)),
-	                  "help:mate-cpufreq-applet/cpufreq-applet-prefs",
-	                  gtk_get_current_event_time (),
-	                  &error);
-#endif
 
                 if (error) {
                         cpufreq_utils_display_error (_("Could not open help document"),
