@@ -555,11 +555,7 @@ static GtkWidget* create_hig_category(GtkWidget* main_box, gchar* title)
 
 	tmp = g_strdup_printf ("<b>%s</b>", title);
 	label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
 	gtk_label_set_markup (GTK_LABEL (label), tmp);
 	g_free (tmp);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
@@ -744,14 +740,10 @@ static void help_cb(GtkDialog* dialog, MateWeatherPref* pref)
 
 	current_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (pref->priv->notebook));
 	uri = g_strdup_printf ("help:mateweather/mateweather-prefs#mateweather-%s", (current_page == 0) ? "metric" : "change-location");
-#if GTK_CHECK_VERSION (3, 22, 0)
 	gtk_show_uri_on_window (GTK_WINDOW (dialog),
 	                        uri,
 	                        gtk_get_current_event_time (),
 	                        &error);
-#else
-	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)), uri, gtk_get_current_event_time (), &error);
-#endif
 	g_free (uri);
 
 	if (error)
@@ -862,11 +854,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	temp_label = gtk_label_new_with_mnemonic (_("_Temperature unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (temp_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (temp_label), GTK_JUSTIFY_LEFT);
-#if GTK_CHECK_VERSION (3, 16, 0)
-	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (temp_label), 0.0, 0.5);
-#endif
+	gtk_label_set_xalign (GTK_LABEL (temp_label), 0.0);
 	gtk_widget_show (temp_label);
 
 	temp_combo = gtk_combo_box_text_new ();
@@ -888,11 +876,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	speed_label = gtk_label_new_with_mnemonic (_("_Wind speed unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (speed_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (speed_label), GTK_JUSTIFY_LEFT);
-#if GTK_CHECK_VERSION (3, 16, 0)
-	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (speed_label), 0.0, 0.5);
-#endif
+	gtk_label_set_xalign (GTK_LABEL (speed_label), 0.0);
 	gtk_widget_show (speed_label);
 
 	speed_combo = gtk_combo_box_text_new ();
@@ -919,11 +903,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	pres_label = gtk_label_new_with_mnemonic (_("_Pressure unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (pres_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (pres_label), GTK_JUSTIFY_LEFT);
-#if GTK_CHECK_VERSION (3, 16, 0)
-	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (pres_label), 0.0, 0.5);
-#endif
+	gtk_label_set_xalign (GTK_LABEL (pres_label), 0.0);
 	gtk_widget_show (pres_label);
 
 	pres_combo = gtk_combo_box_text_new ();
@@ -953,11 +933,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	dist_label = gtk_label_new_with_mnemonic (_("_Visibility unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (dist_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (dist_label), GTK_JUSTIFY_LEFT);
-#if GTK_CHECK_VERSION (3, 16, 0)
-	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (dist_label), 0, 0.5);
-#endif
+	gtk_label_set_xalign (GTK_LABEL (dist_label), 0.0);
 	gtk_widget_show (dist_label);
 
 	dist_combo = gtk_combo_box_text_new ();
@@ -1124,11 +1100,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	gtk_container_add (GTK_CONTAINER (pref->priv->notebook), pref_loc_hbox);
 
 	tree_label = gtk_label_new_with_mnemonic (_("_Select a location:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (tree_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (tree_label), 0.0, 0.5);
-#endif
 	gtk_box_pack_start (GTK_BOX (pref_loc_hbox), tree_label, FALSE, FALSE, 0);
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
